---
title: Shared regulatory pathways reveal novel genetic correlations between grip strength
  and neuromuscular disorders
author: 'Sreemol Gokuladhas (email: sreemol.gokuladhas@auckland.ac.nz)'
date: "12/08/2019"
output:
  pdf_document: default
  html_document: default
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
```

##### Main figures #####

##### input data provided as Supplementary Table 3(3a-3d) for immortalized cell line (ICL) Hi-C datasets and Supplementary Table 4(4a-4d) for psoas muscle tissue (PMT) Hi-C datasets #####

```{r}
gsmuscle <- read.delim("/data/working data/GS_MUSCLE/significant_eqtls.txt")

mgmuscle <- read.delim("data/working data/MG_MUSCLE/significant_eqtls.txt")

msmuscle <- read.delim("data/working data/MS_MUSCLE/significant_eqtls.txt")

alsmuscle <- read.delim("data/working data/ALS_MUSCLE/significant_eqtls.txt")

gs <- read.delim("data/working data/GS_RAO/significant_eqtls.txt")

mg <- read.delim("data/working data/MG_RAO/significant_eqtls.txt")

ms <- read.delim("data/working data/MS_RAO/significant_eqtls.txt")

als <- read.delim("data/working data/ALS_RAO/significant_eqtls.txt")

gs_input <- read.delim("data/individual inputs/gs_input_snps.txt")

mg_input <- read.delim("data/individual inputs/mg_input_snps.txt")

ms_input <- read.delim("data/individual inputs/ms_input_snps.txt")

als_input <- read.delim("data/individual inputs/als_input_snps.txt")
```

##### figure 1c. The proportion of eQTL: non-eQTL SNPs identified using the ICL #####

```{r}

#to find non-eQTL SNPs in ICL dataset (input is all input snps, SNP is eQTL SNPs)

gs_rao_neqtls <- setdiff(gs_input$gsinput, gs$SNP)
mg_rao_neqtls <- setdiff(mg_input$mginput, mg$SNP)
ms_rao_neqtls <- setdiff(ms_input$msinput, ms$SNP)
als_rao_neqtls <- setdiff(als_input$alsinput, als$SNP)

# plotting eQTL vs non-eQTL in ICL

library(ggplot2)
library(reshape2)
require(scales)
df=melt(data.frame(Non_eQTLs=c(0.2625, 0.2777, 0.2105, 0.5111), 
                   eQTLs=c(0.7374, 0.7222, 0.7894, 0.4888),
                     
                     phen=c("GS", "MG", "MS", "ALS")),
          variable.name="snps")
  #to retain the order i.e, otherwise ggplot automatically sorts alphabetically or numerically
  df$phen <- factor(df$phen, levels = c("GS", "MG", "MS", "ALS"))
  df$val <-  c(47, 5, 60, 69, 132, 13, 225, 66)
  ggplot(df, aes(x=phen, y=value, fill=snps)) +
    geom_bar(position= "dodge", width = 0.5, stat="identity") +
    geom_text(aes(x= phen, y=value, group=snps, label=paste0(" ", val)),
              position = position_dodge(width=0.5),
              #label = c("N= 1030", "N= 3982", "N= 504", "N= 125", "N= 47",  "N= 299", "N= 93", "N= 7"),
              #hjust = 1, 
              vjust = -.25,
              size=3)+
    scale_fill_hue(name="snps")+
    xlab("")+ylab("Percentage")+
    scale_fill_manual(name="snps", 
                    values=c("#F9A777", "#8BCAEC"))+
    ggtitle("")+
    theme_classic()+
    scale_y_continuous(labels = scales::percent_format(accuracy = 1), limits=c(0,1), expand = expand_scale(mult = c(0, .1)))
  
```

##### figure 1d. The proportion of eQTL: non-eQTL SNPs identified using the PMT #####

```{r}

#to find non-eQTL SNPs in PMT dataset (input is all input snps, SNP is eQTL SNPs)

gs_muscle_neqtls <- setdiff(gs_input$gsinput, gsmuscle$SNP)
mg_muscle_neqtls <- setdiff(mg_input$mginput, mgmuscle$SNP)
ms_muscle_neqtls <- setdiff(ms_input$msinput, msmuscle$SNP)
als_muscle_neqtls <- setdiff(als_input$alsinput, alsmuscle$SNP)

# plotting eQTL vs non-eQTL in PMT
  df=melt(data.frame(Non_eQTLs=c(0.3631, 0.8888, 0.3508, 0.6074), 
                   eQTLs=c(0.6368, 0.1111, 0.6468, 0.3925),
                     # val=c("N= 1030", "N= 3982", "N= 504", "N= 125", "N= 47",  "N= 299", "N= 93", "N= 7"),
                     phen=c("GS", "MG", "MS", "ALS")),
          variable.name="snps")
  #to retain the order i.e, otherwise ggplot automatically sorts alphabetically or numerically
  df$phen <- factor(df$phen, levels = c("GS", "MG", "MS", "ALS"))
  df$val <-  c(65, 16, 100, 82, 114, 2, 185, 53)
  ggplot(df, aes(x=phen, y=value, fill=snps)) +
    geom_bar(position= "dodge", width = 0.5, stat="identity") +
    geom_text(aes(x= phen, y=value, group=snps, label=paste0(" ", val)),
              position = position_dodge(width=0.5),
              #label = c("N= 1030", "N= 3982", "N= 504", "N= 125", "N= 47",  "N= 299", "N= 93", "N= 7"),
              #hjust = 1, 
              vjust = -.25,
              size=3)+
    scale_fill_hue(name="snps")+
    scale_fill_manual(name="snps", 
                    values=c("#F9A777", "#8BCAEC"))+
    xlab("")+ylab("Percentage")+
    ggtitle("")+
    theme_classic()+
    scale_y_continuous(labels = scales::percent_format(accuracy = 1), limits=c(0,1), expand = expand_scale(mult = c(0, .1)))
  
```

##### figure 1e. Numbers of eQTLs specific to immortalized cell line and psoas muscle, or both Hi-C datasets #####

```{r}

# To find eQTLs specific to immortalised cell line dataset

gs_eqtls_rao <- setdiff(gs$SNP, gsmuscle$SNP)
mg_eqtls_rao <- setdiff(mg$SNP, mgmuscle$SNP)
ms_eqtls_rao <- setdiff(ms$SNP, msmuscle$SNP)
als_eqtls_rao <- setdiff(als$SNP, alsmuscle$SNP)

# To find eQTLs specific to psoas muscle dataset

gs_eqtls_muscle <- setdiff(gsmuscle$SNP, gs$SNP)
mg_eqtls_muscle <- setdiff(mgmuscle$SNP, mg$SNP)
ms_eqtls_muscle <- setdiff(msmuscle$SNP, ms$SNP)
als_eqtls_muscle <- setdiff(alsmuscle$SNP, als$SNP)

# To find eQTLs shared by both immortalised cell line and psoas muscle datasets

gs_rm_overlaps <- intersect(gs$SNP, gsmuscle$SNP)
mg_rm_overlaps <- intersect(mg$SNP, mgmuscle$SNP)
ms_rm_overlaps <- intersect(ms$SNP, msmuscle$SNP)
als_rm_overlaps <- intersect(als$SNP, alsmuscle$SNP)

# plotting eQTLs specific to ICL, PMT and shared

library(tidyverse)
library(reshape2)
dif= melt(data.frame(Immortalised_cell_line_specific_eQTLs=c(31, 11, 59, 25),
                    Shared_eQTLs=c(101, 2, 166, 41),
                    Psoas_muscle_tissue_specific_eQTLs=c(13, 0, 19, 12),
                    lab = c("GS", "MG", "MS", "ALS")),
        variable.name="variants")
dif[dif==0]<-NA
dif$lab <-factor(dif$lab, levels = c("GS", "MG", "MS", "ALS"))
ggplot(dif, aes(x=lab, y=value, fill=variants, label = value))+
  scale_y_continuous(expand=c(0,0), limits = c(0,300))+
  geom_bar(stat="identity", position = "stack", width = 0.4)+
  geom_text(size= 3, hjust = 0.1, vjust = -2.5, position = position_stack(vjust = 0.5))+
  scale_fill_manual(name="variants", 
                    values=c("#84CBA0", "#F7C3B2", "#D3D2D1"))+ 
  xlab("")+ylab("Count")+
  theme_classic()+
  coord_flip()

```

##### figure 2a. Overlap between eGene sets for GS, MG, MS and ALS identified using immortalized cell line Hi-C datasets #####

```{r}
library(UpSetR)
genes <- list(GS=gs$Gene_Name, MG=mg$Gene_Name, MS=ms$Gene_Name, ALS=als$Gene_Name)
upset(fromList(genes), 
      mainbar.y.label = "Overlapping eGenes (#)", #empty.intersections = "on", 
      order.by = "degree", matrix.color = "black", sets.x.label = "eGenes (#)", shade.color = "gray88",
      point.size = 2.5, main.bar.color = "firebrick", line.size = 1, sets.bar.color = "black",
      text.scale = c(1.25,1.25,1.05,1.25,1.25,1.25))
```

##### figure 2b. Overlap between eGene sets for GS, MG, MS and ALS identified using Psoas muscle Hi-C datasets #####

```{r}
genesmuscle <- list(GS=gsmuscle$Gene_Name, MG=mgmuscle$Gene_Name, MS=msmuscle$Gene_Name, 
                    ALS=alsmuscle$Gene_Name)
upset(fromList(genesmuscle), sets.bar.color = "black", 
      mainbar.y.label = "Overlapping eGenes (#)", #empty.intersections = "on", 
      order.by = "degree", matrix.color = "black", shade.color = "gray88",
      point.size = 2.5, main.bar.color = "firebrick", line.size = 1, sets.x.label = "eGenes (#)",
      text.scale = c(1.25,1.25,1.05,1.25,1.25,1.25))
```

##### figure 2c. Bootstrapping values (n=10000) for overlaps between randomly selected gene set (A list of all eGenes from GTEx (V8)) to validate overlaps from the immortalized cell line Hi-C dataset ####

#### python script used for bootstrapping ####

```{python}
from __future__ import division
import random
import numpy as np
import csv

tests = input("Enter number of tests to be done and press enter \n")

print("\n Bootstrapping in process......., Please Wait !!!!!! \n")

temp = []

allgene = list(line.strip() for line in open("all_egenes_gtex_v8.txt"))
f = open('statistics.txt', 'w')
writer = csv.writer(f, delimiter='\t')
header = ['gs_mg', 'gs_ms', 'gs_als', 'mg_ms', 'mg_als', 'ms_als', 'gs_mg_ms', 'gs_mg_als', 'gs_ms_als']
writer.writerow(header)
for i in range(0, tests):
    gs = set(np.random.choice(allgene, 477, replace= True))
    mg = set(np.random.choice(allgene, 98, replace= True))
    ms = set(np.random.choice(allgene, 644 , replace= True))
    als = set(np.random.choice(allgene, 133, replace= True))

    gs_mg = list(gs & mg)
    gs_ms = list(gs & ms)
    gs_als = list(gs & als)
    mg_ms = list(mg & ms)
    mg_als = list(mg & als)
    ms_als = list(ms & als)
    gs_mg_ms = list(gs & mg & ms)
    gs_mg_als = list(gs & mg & als)
    gs_ms_als = list(gs & ms & als)

    len_gs_mg = len(gs_mg)
    len_gs_ms = len(gs_ms)
    len_gs_als = len(gs_als)
    len_mg_ms = len(mg_ms)
    len_mg_als = len(mg_als)
    len_ms_als = len(ms_als)
    len_gs_mg_ms = len(gs_mg_ms)
    len_gs_mg_als = len(gs_mg_als)
    len_gs_ms_als = len(gs_ms_als)

    combined = [len_gs_mg, len_gs_ms, len_gs_als, len_mg_ms, len_mg_als, len_ms_als, len_gs_mg_ms, len_gs_mg_als, len_gs_ms_als]

    writer.writerows([combined])

    if  (len_gs_mg >= 25):
        temp.append(1)
    else:
        pass
    if (len_gs_ms >= 69):
        temp.append(2)
    else:
        pass
    if (len_gs_als >= 8):
        temp.append(3)
    else:
        pass
    if (len_mg_ms >= 30):
        temp.append(4)
    else:
        pass
    if (len_mg_als >= 1):
        temp.append(5)
    else:
        pass
    if (len_ms_als >= 2):
        temp.append(6)
    else:
        pass
    if (len_gs_mg_ms >= 16):
        temp.append(7)
    else:
        pass
    if (len_gs_mg_als >= 1):
        temp.append(8)
    else:
        pass
    if (len_gs_ms_als >= 1):
        temp.append(9)
    else:
        pass

gsmg = temp.count(1)
gsms = temp.count(2)
gsals = temp.count(3)
mgms = temp.count(4)
mgals = temp.count(5)
msals = temp.count(6)
gsmgms = temp.count(7)
gsmgals = temp.count(8)
gsmsals = temp.count(9)

pval_gsmg = gsmg/tests
pval_gsms = gsms/tests
pval_gsals = gsals/tests
pval_mgms = mgms/tests
pval_mgals = mgals/tests
pval_msals = msals/tests
pval_gsmgms = gsmgms/tests
pval_gsmgals = gsmgals/tests
pval_gsmsals = gsmsals/tests

f1 = open('pvalues.txt', 'w')
writer = csv.writer(f1, delimiter = '\t')
header = ['pval_gsmg', 'pval_gsms', 'pval_gsals', 'pval_mgms', 'pval_mgals', 'pval_msals', 'pval_gsmgms', 'pval_gsmgals', 'pval_gsmsals']
writer.writerow(header)
pvalue = [pval_gsmg, pval_gsms, pval_gsals, pval_mgms, pval_mgals, pval_msals, pval_gsmgms, pval_gsmgals, pval_gsmsals]
writer.writerows([pvalue])

f.close()
f1.close()

print("Bootrapping Done!!! \n")
print("Two output files statistics.txt and pvalues.txt are generated. \n")
                                                                                                         
```

```{r}

#results (statistics.txt) from the bootstrap python script is the input here

library(reshape2)
library(ggplot2)

df <- read.delim("results/Analysis/bootstrapping/statistics.txt")

df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  scale_y_continuous(limits = c(0, 80), breaks = c(0, 20, 40, 60, 80))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=9,angle=30,hjust=1,vjust=1,face="plain"))+
   theme(axis.text.y = element_text(colour="grey20",size=9, face="plain")) +
   theme(axis.title.y = element_text(size=9, face="plain"))
  
```

##### figure 2d. Bootstrapping values (n=10000) for overlaps between randomly selected gene set (a list of all eGenes from GTEx (v8)) to validate overlaps from the psoas muscle Hi-C dataset #####

#### python script used to perform bootsrapping 

```{python}
from __future__ import division
import random
import numpy as np
import csv

tests = input("Enter number of tests to be done and press enter \n")

print("\n Bootstrapping in process......., Please Wait !!!!!! \n")

temp = []

allgene = list(line.strip() for line in open("sorted_all_egenes_gtex_v8.txt"))
f = open('statistics_m.txt', 'w')
writer = csv.writer(f, delimiter='\t')
header = ['gs_ms', 'gs_als', 'mg_als']
writer.writerow(header)
for i in range(0, tests):
    gs = set(np.random.choice(allgene, 153, replace= True))
    mg = set(np.random.choice(allgene, 2, replace= True))
    ms = set(np.random.choice(allgene, 266, replace= True))
    als = set(np.random.choice(allgene, 65, replace= True))

    gs_ms = list(gs & ms)
    gs_als = list(gs & als)
    mg_als = list(mg & als)

    len_gs_ms = len(gs_ms)
    len_gs_als = len(gs_als)
    len_mg_als = len(mg_als)

    combined = [len_gs_ms, len_gs_als, len_mg_als]

    writer.writerows([combined])

    if (len_gs_ms >= 6):
        temp.append(1)
    else:
        pass
    if (len_gs_als >= 1):
        temp.append(2)
    else:
        pass
    if (len_mg_als >= 1):
        temp.append(3)
    else:
        pass
gsms = temp.count(1)
gsals = temp.count(2)
mgals = temp.count(3)

pval_gsms = gsms/tests
pval_gsals = gsals/tests
pval_mgals = mgals/tests

f1 = open('pvalues_m.txt', 'w')
writer = csv.writer(f1, delimiter = '\t')
header = ['pval_gsms', 'pval_gsals', 'pval_mgals']
writer.writerow(header)
pvalue = [pval_gsms, pval_gsals, pval_mgals]
writer.writerows([pvalue])

f.close()
f1.close()

print("Bootrapping Done!!! \n")
print("Two output files statistics_m.txt and pvalues_m.txt are generated. \n")
                            
```


```{r}

#results (statistics_m.txt) from the bootstrap python script is the input here
library(reshape2)
library(ggplot2)

df <- read.delim("results/Analysis/bootstrapping/statistics_m.txt")

df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  #scale_fill_manual(values=c("red"))+
  scale_y_continuous(limits = c(0, 8), breaks = c(0, 2, 4,6,8))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=10,angle=30,hjust=1,vjust=1,face="plain"))
```

##### figure 3c. Numbers of overlapping pathways enriched with eGenes from GS, MG, MS and ALS identified from immortalized cell line Hi-C dataset #####

```{r}
gspathway <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/gs_rao_pathways.txt")
mgpathway <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/mg_rao_pathways.txt")
mspathway <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/ms_rao_pathways.txt")
alspathway <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/als_rao_pathways.txt")

library(UpSetR)
raopathways_fig <- list(GS=gspathway$Pathways, MG=mgpathway$Pathways, MS=mspathway$Pathways, ALS=alspathway$Pathways)
upset(fromList(raopathways_fig), sets.bar.color = "skyblue", main.bar.color = "navyblue",
      mainbar.y.label = "Overlapping pathways (#)", #empty.intersections = "on", 
      order.by = "degree",
      point.size = 2.5, line.size = 1, matrix.color = "black", sets.x.label = "pathways (#)",
      text.scale = c(1.25,1.25,1.05,1.25,1.25,1.25))
```

##### figure 3d. Numbers of overlapping pathways enriched with eGenes from GS, MG, MS and ALS identified from psoas muscle tissue Hi-C dataset #####

```{r}
gsmusclepathway <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/gs_muscle_pathways.txt")
mgmusclepathway <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/mg_muscle_pathways.txt")
msmusclepathway <- read.delim("/results/Analysis/pathway/results/txt_files/individual_pathways/ms_muscle_pathways.txt")
alsmusclepathway <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/als_muscle_pathways.txt")

library(UpSetR)
musclepathways_fig <- list(GS=gsmusclepathway$Pathways, MG=mgmusclepathway$Pathways, MS=msmusclepathway$Pathways, ALS=alsmusclepathway$Pathways)
upset(fromList(musclepathways_fig), sets.bar.color = "black", main.bar.color = "cyan4",
      mainbar.y.label = "Overlapping pathways (#)", #empty.intersections = "on", 
      order.by = "degree",
      point.size = 2.5, line.size = 1, matrix.color = "black", sets.x.label = "pathways (#)",
      text.scale = c(1.25,1.25,1.05,1.25,1.25,1.25))
```

##### figure 3e. Bootstrapping values (n=10000) for overlaps between randomly selected pathways (from a list of all KEGG pathways (n = 536)) to validate overlaps from immortalised cell line Hi-C dataset #####

#### python script used to perform bootsrapping

```{python}
from __future__ import division
import random
import numpy as np
import csv

tests = input("Enter number of tests to be done and press enter \n")

print("\n Bootstrapping in process......., Please Wait !!!!!! \n")

temp = []

all_pathways = list(line.strip() for line in open("rao/allpathways/KEGG_paths.txt"))
f = open('pathway_bootstrap_statistics.txt', 'w')
writer = csv.writer(f, delimiter='\t')
header = ['gs_mg', 'gs_ms', 'gs_als', 'mg_ms', 'mg_als', 'ms_als', 'gs_mg_ms', 'gs_mg_als', 'gs_ms_als', 'mg_ms_als', 'gs_mg_ms_als']
writer.writerow(header)
for i in range(0, tests):
    gs = set(np.random.choice(all_pathways, 90, replace= True))
    mg = set(np.random.choice(all_pathways, 27, replace= True))
    ms = set(np.random.choice(all_pathways, 105, replace= True))
    als = set(np.random.choice(all_pathways, 25, replace= True))

    gs_mg = list(gs & mg)
    gs_ms = list(gs & ms)
    gs_als = list(gs & als)
    mg_ms = list(mg & ms)
    mg_als = list(mg & als)
    ms_als = list(ms & als)
    gs_mg_ms = list(gs & mg & ms)
    gs_mg_als = list(gs & mg & als)
    gs_ms_als = list(gs & ms & als)
    mg_ms_als = list(mg & ms & als)
    gs_mg_ms_als = list(gs & mg & ms & als)

    len_gs_mg = len(gs_mg)
    len_gs_ms = len(gs_ms)
    len_gs_als = len(gs_als)
    len_mg_ms = len(mg_ms)
    len_mg_als = len(mg_als)
    len_ms_als = len(ms_als)
    len_gs_mg_ms = len(gs_mg_ms)
    len_gs_mg_als = len(gs_mg_als)
    len_gs_ms_als = len(gs_ms_als)
    len_mg_ms_als = len(mg_ms_als)
    len_gs_mg_ms_als = len(gs_mg_ms_als)

    combined = [len_gs_mg, len_gs_ms, len_gs_als, len_mg_ms, len_mg_als, len_ms_als, len_gs_mg_ms, len_gs_mg_als, len_gs_ms_als, len_mg_ms_als, len_gs_mg_ms_als]

    writer.writerows([combined])

    if  (len_gs_mg >= 24):
        temp.append(1)
    else:
        pass
    if (len_gs_ms >= 69):
        temp.append(2)
    else:
        pass
    if (len_gs_als >= 17):
        temp.append(3)
    else:
        pass
    if (len_mg_ms >= 18):
        temp.append(4)
    else:
        pass
    if (len_mg_als >= 5):
        temp.append(5)
    else:
        pass
    if (len_ms_als >= 19):
        temp.append(6)
    else:
        pass
    if (len_gs_mg_ms >= 16):
        temp.append(7)
    else:
        pass
    if (len_gs_mg_als >= 4):
        temp.append(8)
    else:
        pass
    if (len_gs_ms_als >= 14):
        temp.append(9)
    else:
        pass
    if (len_mg_ms_als >= 4):
        temp.append(10)
    else:
        pass
    if (len_gs_mg_ms_als >= 3):
        temp.append(11)
    else:
        pass

gsmg = temp.count(1)
gsms = temp.count(2)
gsals = temp.count(3)
mgms = temp.count(4)
mgals = temp.count(5)
msals = temp.count(6)
gsmgms = temp.count(7)
gsmgals = temp.count(8)
gsmsals = temp.count(9)
mgmsals = temp.count(10)
gsmgmsals = temp.count(11)

pval_gsmg = gsmg/tests
pval_gsms = gsms/tests
pval_gsals = gsals/tests
pval_mgms = mgms/tests
pval_mgals = mgals/tests
pval_msals = msals/tests
pval_gsmgms = gsmgms/tests
pval_gsmgals = gsmgals/tests
pval_gsmsals = gsmsals/tests
pval_mgmsals = mgmsals/tests
pval_gsmgmsals = gsmgmsals/tests

f1 = open('pathway_bootstrap_pvalues.txt', 'w')
writer = csv.writer(f1, delimiter = '\t')
header = ['pval_gsmg', 'pval_gsms', 'pval_gsals', 'pval_mgms', 'pval_mgals', 'pval_msals', 'pval_gsmgms', 'pval_gsmgals', 'pval_gsmsals', 'pval_mgmsals', 'pval_gsmgmsals']
writer.writerow(header)
pvalue = [pval_gsmg, pval_gsms, pval_gsals, pval_mgms, pval_mgals, pval_msals, pval_gsmgms, pval_gsmgals, pval_gsmsals, pval_mgmsals, pval_gsmgmsals]
writer.writerows([pvalue])

f.close()
f1.close()

print("Bootrapping Done!!! \n")
print("Two output files pathway_bootstrap_statistics.txt and pathway_bootstrap_pvalues.txt are generated. \n")

```

```{r}
library(reshape2)
library(ggplot2)

df <- read.delim("results/Analysis/bootstrapping/pathway_bootstrap_statistics.txt")
df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  #scale_fill_manual(values=c("red"))+
  scale_y_continuous(limits = c(0, 70), breaks = c(0,10,20,30,40,50,60,70))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=9,angle=30,hjust=1,vjust=1,face="plain"))+
   theme(axis.text.y = element_text(colour="grey20",size=9, face="plain")) +
   theme(axis.title.y = element_text(size=9, face="plain"))
```

##### figure 3f. Bootstrapping values (n=10000) for overlaps between randomly selected pathways (from a list of all KEGG pathways (n = 536)) to validate overlaps from the psoas muscle Hi-C dataset #####

#### python script used to perform bootsrapping

```{python}
from __future__ import division
import random
import numpy as np
import csv

tests = input("Enter number of tests to be done and press enter \n")

print("\n Bootstrapping in process......., Please Wait !!!!!! \n")

temp = []

all_pathways = list(line.strip() for line in open("/muscle/allpathways/KEGG_paths.txt"))
f = open('pathway_bootstrap_statistics_muscle.txt', 'w')
writer = csv.writer(f, delimiter='\t')
header = ['gs_ms', 'gs_als', 'mg_ms', 'ms_als', 'gs_ms_als']
writer.writerow(header)
for i in range(0, tests):
    gs = set(np.random.choice(all_pathways, 39, replace= True))
    mg = set(np.random.choice(all_pathways, 1, replace= True))
    ms = set(np.random.choice(all_pathways, 93, replace= True))
    als = set(np.random.choice(all_pathways, 15, replace= True))

    gs_ms = list(gs & ms)
    gs_als = list(gs & als)
    mg_ms = list(mg & ms)
    ms_als = list(ms & als)
    gs_ms_als = list(gs & ms & als)

    len_gs_ms = len(gs_ms)
    len_gs_als = len(gs_als)
    len_mg_ms = len(mg_ms)
    len_ms_als = len(ms_als)
    len_gs_ms_als = len(gs_ms_als)

    combined = [len_gs_ms, len_gs_als, len_mg_ms, len_ms_als, len_gs_ms_als]

    writer.writerows([combined])

    if (len_gs_ms >= 21):
        temp.append(1)
    else:
        pass
    if (len_gs_als >= 5):
        temp.append(2)
    else:
        pass
    if (len_mg_ms >= 1):
        temp.append(3)
    else:
        pass
    if (len_ms_als >= 10):
        temp.append(4)
    else:
        pass
    if (len_gs_ms_als >= 5):
        temp.append(5)
    else:
        pass

gsms = temp.count(1)
gsals = temp.count(2)
mgms = temp.count(3)
msals = temp.count(4)
gsmsals = temp.count(5)

pval_gsms = gsms/tests
pval_gsals = gsals/tests
pval_mgms = mgms/tests
pval_msals = msals/tests
pval_gsmsals = gsmsals/tests

f1 = open('pathway_bootstrap_pvalues_muscle.txt', 'w')
writer = csv.writer(f1, delimiter = '\t')
header = ['pval_gsms', 'pval_gsals', 'pval_mgms', 'pval_msals', 'pval_gsmsals']
writer.writerow(header)
pvalue = [pval_gsms, pval_gsals, pval_mgms, pval_msals, pval_gsmsals]
writer.writerows([pvalue])

f.close()
f1.close()

print("Bootrapping Done!!! \n")
print("Two output files pathway_bootstrap_statistics_muscle.txt and pathway_bootstrap_pvalues_muscle.txt are generated. \n")

```

```{r}
library(reshape2)
library(ggplot2)
df <- read.delim("/muscle/allpathways/pathway_bootstrap_statistics_muscle.txt")

df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  #scale_fill_manual(values=c("red"))+
  scale_y_continuous(limits = c(0, 21), breaks = c(0,3,6,9,12,15,18,21))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=9,angle=30,hjust=1,vjust=1,face="plain"))+
   theme(axis.text.y = element_text(colour="grey20",size=9, face="plain")) +
   theme(axis.title.y = element_text(size=9, face="plain"))
```

##### figure 5a. shared druggable eGenes #####

```{r}
gsdruggene <- read.delim("results/Analysis/druggability/gsdrug/gs_rao_druggable_genes.txt")
gsdruggene <- unique(gsdruggene$Gene_Name)
mgdruggene <- read.delim("results/Analysis/druggability/mgdrug/mg_rao_druggable_genes.txt")
mgdruggene <- unique(mgdruggene$Gene_Name)
msdruggene <- read.delim("results/Analysis/druggability/msdrug/ms_rao_druggable_genes.txt")
msdruggene <- unique(msdruggene$Gene_Name)
alsdruggene <- read.delim("results/Analysis/druggability/alsdrug/als_rao_druggable_genes.txt")
alsdruggene <- unique(alsdruggene$Gene_Name)

library(UpSetR)
dgr <- list(GS = gsdruggene, MG = mgdruggene, 
            MS = msdruggene, ALS = alsdruggene)
upset(fromList(dgr), sets.bar.color = "black", 
      mainbar.y.label = "Overlapping druggable eGenes (#)", #empty.intersections = "on", 
      order.by = "degree", matrix.color = "black", shade.color = "gray88",
      point.size = 2.5, main.bar.color = "firebrick", line.size = 1, 
      sets.x.label = "druggable eGenes (#)", 
      text.scale = c(1.25,1.25,1.05,1.25,1.25,1.5))
```

##### figure 5b. Shared druggable pathways #####

##### 1. to rearrange pathway and genes table (tidying up using python script) #####
##### 2. to search for druggable pathway using druggable eGene (using sqldf function in R) #####
##### 3. Plotting druggable pathways using upsetR package #####

```{python, python.reticulate = FALSE}

# 1. to tidy up the pathway table

#! /usr/bin/env python
import csv

def tidy_table():
    f = open('/path/to/input/file/.txt', 'r')
    reader = csv.reader(f, delimiter='\t')
    to_file = []
    for row in reader:
        pathway = row[0]
        genes = row[1].split(", ")
        for gene in genes:
            to_file.append((row[0], gene))
    output_file = open('/path/to/output/file/.txt', 'w')
    writer = csv.writer(output_file, delimiter='\t')
    writer.writerow(['pathway', 'genes'])
    writer.writerows(to_file)
    output_file.close()

if __name__=='__main__':
    tidy_table()
    
#This will generate a file with two columns pathways and genes.
```


```{r}
# 2. to search for druggable pathway from druggable gene

#results from the above script (i.e. tidied pathway table) is the input for this chunk of code)

gspathtidy <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/gs_rao_pathways_tidied.txt")
mgpathtidy <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/mg_rao_pathways_tidied.txt")
mspathtidy <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/ms_rao_pathways_tidied.txt")
alspathtidy <- read.delim("results/Analysis/pathway/results/txt_files/individual_pathways/als_rao_pathways_tidied.txt")

library(sqldf)
library(data.table)
require(plyr)

# GS druggable pathways 
gsdgene <- list(gsdruggene)
setDT(gsdgene)
gsdruggablepathway <- sqldf('SELECT pathway from gspathtidy WHERE genes IN gsdgene')
gsdruggablepathway <- unique(gsdruggablepathway)
print(gsdruggablepathway)

# MG druggable pathways
mgdgene <- list(mgdruggene)
setDT(mgdgene)
mgdruggablepathway <- sqldf('SELECT pathway from mgpathtidy WHERE genes IN mgdgene')
mgdruggablepathway <- unique(mgdruggablepathway)
print(mgdruggablepathway)

# MS druggable pathways
msdgene <- list(msdruggene)
setDT(msdgene)
msdruggablepathway <- sqldf('SELECT pathway from mspathtidy WHERE genes IN msdgene')
msdruggablepathway <- unique(msdruggablepathway)
print(msdruggablepathway)

# ALS druggable pathways
alsdgene <- list(alsdruggene)
setDT(alsdgene)
alsdruggablepathway <- sqldf('SELECT pathway from alspathtidy WHERE genes IN alsdgene')
alsdruggablepathway <- unique(alsdruggablepathway)
print(alsdruggablepathway)

```

```{r}
# 3. Plotting druggable pathways using upsetR package

dpr <- list(GS = gsdruggablepathway$pathway, MG = mgdruggablepathway$pathway, MS = msdruggablepathway$pathway,
            ALS = alsdruggablepathway$pathway)
upset(fromList(dpr), sets.bar.color = "black", 
      mainbar.y.label = "Overlapping druggable pathways (#)", #empty.intersections = "on", 
      order.by = "degree", matrix.color = "black", shade.color = "gray88",
      point.size = 2.5, main.bar.color = "cyan4", line.size = 1, 
      sets.x.label = "druggable pathways (#)",
      text.scale = c(1.25,1.25,1.05,1.25,1.25,1.5))
```

##### Supplementary Figures #####

##### Supplementary figure 1. eQTL-eGene pairs specific to immortalized cell line and psoas muscle Hi-C dataset and shared between them #####

```{r}

library(tidyverse)
library(reshape2)
df= melt(data.frame(Immortalized_cell_line_specific=c(501, 109, 646, 101),
                    overlaps=c(100, 2, 190, 40),
                    Muscle_specific=c(73, 0, 136, 33),
                    lab = c("GS", "MG", "MS", "ALS")),
        variable.name="variants")
df[df==0]<-NA
df$lab <-factor(df$lab, levels = c("GS", "MG", "MS", "ALS"))
ggplot(df, aes(x=lab, y=value, fill=variants, label = value))+
  scale_y_continuous(expand=c(0,0), limits = c(0,1000))+
  geom_bar(stat="identity", position = "stack", width = 0.4)+
  geom_text(size= 3, hjust = 0.1, vjust = -2.5, position = position_stack(vjust = 0.5))+
  scale_fill_manual(name="variants", values =c("#84CBA0", "#F7C3B2", "#D3D2D1"))+
  guides(fill=guide_legend(title="eQTL-eGene pairs"))+
  xlab("")+ylab("Count")+
  theme_classic()+
  coord_flip()
```

##### Supplementary figure 2 (left). Bootstrapping values (n=10000) for overlaps between randomly selected gene set (A list of all genes having spatial interaction with all (GS, MG, MS and ALS) SNPs) to validate overlaps from the immortalized cell line Hi-C dataset ####

```{r}
library(reshape2)
library(ggplot2)
df <- read.delim("/hic/rao/hicgenes_bootstrap_statistics.txt")

df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  #scale_fill_manual(values=c("red"))+
  scale_y_continuous(limits = c(0, 80), breaks = c(0, 20, 40, 60, 80))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=9,angle=30,hjust=1,vjust=1,face="plain"))+
   theme(axis.text.y = element_text(colour="grey20",size=9, face="plain")) +
   theme(axis.title.y = element_text(size=9, face="plain"))

```

##### Supplementary figure 2 (right). Bootstrapping values (n=10000) for overlaps between randomly selected gene set (A list of all genes having spatial interaction with all (GS, MG, MS and ALS) SNPs) to validate overlaps from the psoas muscle Hi-C dataset ####

```{r}
library(reshape2)
library(ggplot2)
df <- read.delim("/hic/muscle/hic_bootstrap_statistics_muscle.txt")

df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  #scale_fill_manual(values=c("red"))+
  scale_y_continuous(limits = c(0, 20), breaks = c(0, 5, 10, 15, 20))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=9,angle=30,hjust=1,vjust=1,face="plain"))+
   theme(axis.text.y = element_text(colour="grey20",size=9, face="plain")) +
   theme(axis.title.y = element_text(size=9, face="plain"))

```

##### Supplementary figure 3. LD matrix from all the SNPs on chromosome 6 #####

##### Matrix of R-square values obtained from LDlink (online LD calculator) is the input file #####

```{r}
library(grDevices)
library(LDheatmap)

gs_ld <- as.matrix(read.table("/LD/chr6_all.txt"))

colfunc <- colorRampPalette(c("red", "#FCF4A3"))
colfunc(9)

pushViewport(viewport(width=0.5, height=0.5))
myheatmap <- LDheatmap(gs_ld, genetic.distances = NULL, distances = "physical",
          LDmeasure ="r", add.map = TRUE, add.key = F,
          geneMapLocation = 0.15, geneMapLabelX=NULL, geneMapLabelY = NULL,
          SNP.name = NULL, title = NULL,
          color= colfunc(9), newpage=TRUE,
          name="ldheatmap", vp.name=NULL, pop=TRUE, flip=TRUE, text=T)

grid.edit(gPath("ldheatmap", "heatMap", "heatmap"), gp = gpar(col = "white", lwd = 1))
```

##### Supplementary figure 5. GS and MG eGenes identified from immortalized cell lines share pathways #####

```{r}


library(reshape2)
library(sqldf)
#my own program
data <- read.delim("R_scripts/Supplementary_figures/gsmg_py_out.txt",
                   header = TRUE) 
data <- unique(data)
gs = sqldf('SELECT category, Genes, Phenotype from data WHERE Phenotype = "GS"')
mg = sqldf('SELECT category, Genes, Phenotype from data WHERE Phenotype = "MG"')

gs$category <- as.character(gs$category)
gs$count <- as.numeric(ave(gs$category, gs$category, FUN = length))

mg$category <- as.character(mg$category)
mg$count <- as.numeric(ave(mg$category, mg$category, FUN = length))

gsp <- data.frame(category = gs$category, phenotype = gs$Phenotype, count = gs$count)
mgp <- data.frame(category = mg$category, phenotype = mg$Phenotype, count = mg$count) 

dd <- rbind(gsp, mgp)

ggplot(dd, aes(x = category, y = count))+
  geom_bar(stat = "identity", position = "identity", fill="firebrick")+
  coord_flip()+
  ylab("Number of eGenes")+
  xlab("Pathways")+
  theme_bw()+
  scale_y_continuous(expand = c(0,0.5), limits = c(0,25))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
        panel.spacing = unit(0.75, "lines"))+
  facet_grid(~phenotype, scales = "fixed", space = "fixed")
```

##### Supplementary figure 6. GS and MS eGenes identified from immortalized cell lines share pathways #####

```{r}

data <- read.delim("/R_scripts/Supplementary_figures/gsms_py_out.txt",
                   header = TRUE) 
data <- unique(data)
gs = sqldf('SELECT category, Genes, Phenotype from data WHERE Phenotype = "GS"')
ms = sqldf('SELECT category, Genes, Phenotype from data WHERE Phenotype = "MS"')

gs$category <- as.character(gs$category)
gs$count <- as.numeric(ave(gs$category, gs$category, FUN = length))

ms$category <- as.character(ms$category)
ms$count <- as.numeric(ave(ms$category, ms$category, FUN = length))

gsp <- data.frame(category = gs$category, phenotype = gs$Phenotype, count = gs$count)
msp <- data.frame(category = ms$category, phenotype = ms$Phenotype, count = ms$count) 

dd <- rbind(gsp, msp)

ggplot(dd, aes(x = category, y = count))+
  geom_bar(stat = "identity", position = "identity", fill="firebrick")+
  coord_flip()+
  ylab("Number of eGenes")+
  xlab("Pathways")+
  theme_bw()+
  scale_y_continuous(expand = c(0,0.5))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
        panel.spacing = unit(0.5, "lines"))+
  facet_grid(~phenotype, scales = "fixed", space = "fixed")
```

##### Supplementary figure 7. GS and ALS eGenes identified from immortalized cell lines share pathways #####

```{r}

data <- read.delim("R_scripts/Supplementary_figures/gsals_py_out.txt",
                   header = TRUE) 
data <- unique(data)
gs = sqldf('SELECT category, Genes, Phenotype from data WHERE Phenotype = "GS"')
als = sqldf('SELECT category, Genes, Phenotype from data WHERE Phenotype = "ALS"')

gs$category <- as.character(gs$category)
gs$count <- as.numeric(ave(gs$category, gs$category, FUN = length))

als$category <- as.character(als$category)
als$count <- as.numeric(ave(als$category, als$category, FUN = length))

gsp <- data.frame(category = gs$category, phenotype = gs$Phenotype, count = gs$count)
alsp <- data.frame(category = als$category, phenotype = als$Phenotype, count = als$count) 

dd <- rbind(gsp, alsp)
dd$phenotype <- factor(dd$phenotype, levels = c("GS", "ALS"))
ggplot(dd, aes(x = category, y = count))+
  geom_bar(stat = "identity", position = "identity", fill="firebrick")+
  coord_flip()+
  ylab("Number of eGenes")+
  xlab("Pathways")+
  theme_bw()+
  scale_y_continuous(expand = c(0.01, 0.01))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
        panel.spacing = unit(0.5, "lines"))+
  facet_grid(~phenotype, scales = "free", space = "fixed")
```

##### Supplementary figure 9 (right). Bootstrapping values (n=10000) for overlaps between randomly selected pathways (from a set of all pathways containing phenotype associated eGenes (n = 267)) to validate overlaps from the immortalised cell line Hi-C dataset #####

```{r}
df <- read.delim("/rao/phenotype_pathways/raopathway_bootstrap_statistics.txt")

df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  #scale_fill_manual(values=c("red"))+
  scale_y_continuous(limits = c(0, 70), breaks = c(0,10,20,30,40,50,60,70))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=9,angle=30,hjust=1,vjust=1,face="plain"))+
   theme(axis.text.y = element_text(colour="grey20",size=9, face="plain")) +
   theme(axis.title.y = element_text(size=9, face="plain"))
```


##### Supplementary figure 9 (right). Bootstrapping values (n=10000) for overlaps between randomly selected pathways (from a set of all pathways containing phenotype associated eGenes (n = 247)) to validate overlaps from the psoas muscle Hi-C dataset #####

```{r}
library(reshape2)
library(ggplot2)
df <- read.delim("/muscle/phenopathways/pathway_bootstrap_statistics_muscle.txt")

df$highlight <- c(TRUE, rep(FALSE, nrow(df) - 1L))
df_1 <- melt(df)
ggplot(subset(df_1, !highlight), aes(x=variable, y=value)) +
stat_boxplot(geom ='errorbar', width = 0.2, size= 0.2) + 
  geom_boxplot(fill="palevioletred2", color="black", outlier.size = -0.5, lwd=0.2)+
  geom_point(                               
    data=subset(df_1, highlight), shape=20, size = 3, aes(fill = highlight))+
  #scale_fill_manual(values=c("red"))+
  scale_y_continuous(limits = c(0, 25), breaks = c(0,5,10,15,20,25))+
  xlab("")+
  ylab("# of overlapping genes found per bootstrap run")+
  theme_classic()+
  theme(axis.text.x = element_text(colour="grey20",size=9,angle=30,hjust=1,vjust=1,face="plain"))+
   theme(axis.text.y = element_text(colour="grey20",size=9, face="plain")) +
   theme(axis.title.y = element_text(size=9, face="plain"))
```

